<div class="panel nice-padding panel-upgrade-notification">
	<div class="help-block help-warning">
		You have not setup any tracking for your site.
		<a href="{{ url("wagtailsettings:edit", 'coop', 'analyticssettings', request.site.pk) }}">
			Add your relevant IDs
		</a> to setup
		<a href="https://developers.google.com/tag-manager/">Google Tag Manager</a> or
		<a href="https://developers.google.com/analytics/devguides/collection/analyticsjs/">Google Analytics</a>
	</div>
</div>
